Список изменений
================

2.1.2 (2023-11-27)
------------------
* Экспортируемые объекты и функции добавлены в  __all__

2.1.1 (2023-11-27)
------------------
* Добавлен py.typed

2.1.0 (2023-11-27)
------------------
* Минимальная версия Python 3.10
* Обновлены зависимости
* Переход на rye, ruff и pyright

2.0.0 (2020-09-08)
------------------
* Изменены все сигнатуры - сессия aiohttp передается в явном виде
* Минимальная версия Python 3.8
* Полная анотация типов и проверкой `MyPy <https://mypy.readthedocs.io/en/stable/>`_
* Рефакторинг с учетом требований `wemake-python-styleguide <https://wemake-python-stylegui.de/en/latest/>`_

1.2.2 (2018-12-07)
------------------
* Исправлена ошибка при обработке некоторых пустых ответов MOEX ISS

1.2.1 (2018-12-01)
------------------
* Добавлена дополнительная проверка версии при установке

1.2.0 (2018-11-28)
------------------
* Добавлена функция получения интервала дат, доступных в истории для рынка по заданному режиму торгов get_board_dates()

1.1.1 (2018-11-27)
------------------
* Для исторических котировок в перечень загружаемых по умолчанию колонок добавлены режим торгов и объем в рублях

1.1.0 (2018-11-27)
------------------
* Добавлена функция получения справочника разделов MOEX ISS get_reference()
* Добавлены функции для получения исторических данных по свечкам get_market_candle_borders(), get_market_candles(), get_board_candle_borders() и get_board_candles()
* Добавлена группировка функций в документации
* Удалена функция get_index_history() - эквивалентна вызову get_board_history('MCFTRR', start, end, columns, 'RTSI', 'index')

1.0.1 (2018-11-25)
------------------
* Добавлено сравнение скорости

1.0.0 (2018-11-24)
------------------
* Начальная версия
